@@ -1,3 +1,5 @@
+#define QT_FEATURE_version_tagging 1
+
 #define QT_FEATURE_shared 1
 
 #define QT_FEATURE_static -1
@@ -34,6 +36,8 @@
 
 #define QT_FEATURE_wasm_exceptions -1
 
+#define QT_FEATURE_wasm_jspi -1
+
 #define QT_FEATURE_zstd 1
 
 #define QT_FEATURE_thread 1
@@ -50,12 +54,14 @@
 
 #define QT_FEATURE_opensslv30 1
 
+#define QT_FEATURE_test_gui 1
 
-#define QT_VERSION_STR "6.7.0"
+
+#define QT_VERSION_STR "6.9.0"
 
 #define QT_VERSION_MAJOR 6
 
-#define QT_VERSION_MINOR 7
+#define QT_VERSION_MINOR 9
 
 #define QT_VERSION_PATCH 0
 
@@ -63,4 +69,8 @@
 #define QT_LARGEFILE_SUPPORT 64
 #define QT_VISIBILITY_AVAILABLE
 #define QT_COMPILER_SUPPORTS_NEON 1
+#define QT_COMPILER_SUPPORTS_CRYPTO 1
+#define QT_COMPILER_SUPPORTS_AES 1
+#define QT_COMPILER_SUPPORTS_SVE 1
 #define QT_LINKED_OPENSSL
+#define QT_GUI_TEST 1
