@@ -6,12 +6,18 @@
 
 #define QT_FEATURE_directwrite3 -1
 
+#define QT_FEATURE_directwritecolrv1 -1
+
 #define QT_FEATURE_direct2d -1
 
 #define QT_FEATURE_direct2d1_1 -1
 
+#define QT_FEATURE_emojisegmenter 1
+
 #define QT_FEATURE_evdev 1
 
+#define QT_FEATURE_vxworksevdev -1
+
 #define QT_FEATURE_freetype 1
 
 #define QT_FEATURE_system_freetype 1
@@ -118,5 +124,7 @@
 
 #define QT_FEATURE_raster_fp 1
 
+#define QT_FEATURE_qtgui_threadpool 1
+
 #define QT_FEATURE_graphicsframecapture -1
 
